@@ -242,6 +242,10 @@ void print_job_header (void)
 		case fmtGenpafBlastNoHeader:
 			; // (do nothing)
 			break;
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
+			; // (do nothing)
+			break;
 		case fmtText:
 		case fmtZeroText:
 		text_format:
@@ -332,6 +336,10 @@ void print_job_footer (void)
 		case fmtGenpafBlastNoHeader:
 			; // (do nothing)
 			break;
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
+			; // (do nothing)
+			break;
 		case fmtText:
 		case fmtZeroText:
 		text_format:
@@ -460,6 +468,10 @@ void print_header (void)
 		case fmtGenpafBlastNoHeader:
 			; // (do nothing)
 			break;
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
+			; // (do nothing)
+			break;
 		case fmtText:
 		case fmtZeroText:
 		text_format:
@@ -632,6 +644,8 @@ void print_align_list (alignel* alignList)
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 			print_genpaf_align_list (currParams->outputFile,
 			                         alignList, currParams->seq1, currParams->seq2,
 			                         currParams->outputInfo);
@@ -802,6 +816,8 @@ void print_match (unspos pos1, unspos pos2, unspos length, score s, u64 hspId)
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 			print_genpaf_match (currParams->outputFile,
 			                    currParams->seq1, pos1,
 			                    currParams->seq2, pos2, length,
@@ -916,6 +932,8 @@ char* print_comment_open (void)
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 			commentPrefix = "#";
 			break;
 		case fmtText:
@@ -983,6 +1001,8 @@ void print_comment_close (void)
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 		case fmtText:
 		case fmtZeroText:
 		case fmtHspComp:
@@ -1041,6 +1061,8 @@ void print_m_stanza (census* cen)
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 		case fmtText:
 		case fmtZeroText:
 		case fmtHspComp:
@@ -1092,6 +1114,8 @@ void print_census_stanza (census* cen)
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 		case fmtText:
 		case fmtZeroText:
 		case fmtHspComp:
@@ -1146,6 +1170,8 @@ void print_x_stanza (unspos numMasked)
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 		case fmtText:
 		case fmtZeroText:
 		case fmtHspComp:
@@ -1231,6 +1257,8 @@ void print_generic
 		case fmtGenpafNameHeader:
 		case fmtGenpafBlast:
 		case fmtGenpafBlastNoHeader:
+		case fmtGenpafPafWfMash:
+		case fmtGenpafPafMinimap2:
 		case fmtHspComp:
 		case fmtDiffs:
 		case fmtDiffsNoBlocks:
